package com.tcctlo.law.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.common.core.domain.AjaxResult;
import com.tcctlo.law.entity.DemandPaymentRecord;
import com.tcctlo.law.service.IDemandPaymentRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
 * 金额催收记录 前端控制器
 * </p>
 *
 * @author
 * @since 2025-02-27
 */

@RestController
@RequestMapping("/demandPaymentRecord")
public class DemandPaymentRecordController {


    @Autowired
    private IDemandPaymentRecordService iDemandPaymentRecordService;


    /**
     * 根据案件ID对案件进行催收
     *
     * @param params 参数
     * @return 结果集
     */
    @PostMapping(value = "/caseCollection")
    public AjaxResult caseCollection(@RequestBody Map<String, Long> params) {
        AjaxResult ajaxResult = new AjaxResult();
        if (iDemandPaymentRecordService.caseCollection(params)) {
            ajaxResult.put("msg", "催费成功！");
            ajaxResult.put("code", 200);
        }else {
            ajaxResult.put("msg", "催费失败！");
            ajaxResult.put("code", 500);
        }
        return ajaxResult;
    }

    /**
     * 设置催收消息已读
     * @param params 参数
     * @return 结果集
     */
    @PostMapping("/setRead")
    public AjaxResult setRead(@RequestBody Map<String, Object> params) {
        AjaxResult ajaxResult = new AjaxResult();
        if (iDemandPaymentRecordService.setRead(params)) {
            ajaxResult.put("msg", "设置成功！");
            ajaxResult.put("code", 200);
        }else {
            ajaxResult.put("msg", "设置失败！");
            ajaxResult.put("code", 500);
        }
        return ajaxResult;
    }

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<DemandPaymentRecord> pageList = iDemandPaymentRecordService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        DemandPaymentRecord demandPaymentRecord = iDemandPaymentRecordService.getById(id);
        return AjaxResult.success(demandPaymentRecord);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody DemandPaymentRecord params) {
        Integer result = iDemandPaymentRecordService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iDemandPaymentRecordService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody DemandPaymentRecord params) {
        Integer result = iDemandPaymentRecordService.update(params);
        return AjaxResult.success(result);
    }
}
