package com.tcctlo.law.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctlo.common.core.domain.model.LoginUser;
import com.tcctlo.common.utils.SecurityUtils;
import com.tcctlo.law.entity.AuditRecord;
import com.tcctlo.law.mapper.AuditRecordMapper;
import com.tcctlo.law.mapper.CaseInformationMapper;
import com.tcctlo.law.service.IAuditRecordService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;

/**
* <p>
* 审核记录表 服务实现类
* </p>
*
* @author 
* @since 2025-02-25
*/
@Service
public class AuditRecordServiceImpl extends ServiceImpl<AuditRecordMapper,AuditRecord> implements IAuditRecordService {


    @Resource
    private AuditRecordMapper auditRecordMapper;

    @Resource
    private CaseInformationMapper caseInformationMapper;

    @Override
    public Page<AuditRecord> list(Integer pageNo, Integer pageSize) {
        return auditRecordMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }

    @Override
    public AuditRecord getById(Long id) {
        AuditRecord auditRecord = auditRecordMapper.selectById(id);
        return auditRecord;
    }

    @Override
    public Boolean create(AuditRecord auditRecord) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        Long userId = loginUser.getUserId();
        String username = loginUser.getUsername();
        String nickName = loginUser.getUser().getNickName();
        auditRecord.setUserId(userId);
        auditRecord.setUserName(nickName);
        caseInformationMapper.updateAuditStatusInt(auditRecord.getCaseId(), auditRecord.getAuditResult());
        return auditRecordMapper.insert(auditRecord) > 0;
    }

    @Override
    public Integer delete(Long id) {
        return auditRecordMapper.deleteById(id);
    }

    @Override
    public Integer update(AuditRecord auditRecord) {
        return auditRecordMapper.updateById(auditRecord);
    }

    @Override
    public List<AuditRecord> selectByCaseId(Long caseId) {
        return auditRecordMapper.selectByCaseId(caseId);
    }

}
