package com.tcctlo.law.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctlo.common.core.domain.LawUserVO;
import com.tcctlo.law.entity.CaseLawyer;
import com.tcctlo.law.entity.TransferParam;
import com.tcctlo.law.mapper.CaseInformationMapper;
import com.tcctlo.law.mapper.CaseLawyerMapper;
import com.tcctlo.law.service.ICaseLawyerService;
import com.tcctlo.system.mapper.SysUserMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
* <p>
* 案件律师表 服务实现类
* </p>
*
* @author 张世琪
* @since 2025-02-06
*/
@Service
public class CaseLawyerServiceImpl extends ServiceImpl<CaseLawyerMapper,CaseLawyer> implements ICaseLawyerService {


    @Resource
    private CaseLawyerMapper caseLawyerMapper;

    @Resource
    private SysUserMapper sysUserMapper;

    @Resource
    private CaseInformationMapper caseInformationMapper;

    @Override
    public Page<CaseLawyer> list(Integer pageNo, Integer pageSize) {
        return caseLawyerMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }

    @Override
    public CaseLawyer getById(Long id) {
        CaseLawyer caseLawyer = caseLawyerMapper.selectById(id);
        return caseLawyer;
    }

    @Override
    public Integer create(CaseLawyer caseLawyer) {
        return caseLawyerMapper.insert(caseLawyer);
    }

    @Override
    public Integer delete(Long id) {
        return caseLawyerMapper.deleteById(id);
    }

    @Override
    public Integer update(CaseLawyer caseLawyer) {
        return caseLawyerMapper.updateById(caseLawyer);
    }

    @Override
    public List<CaseLawyer> selectByCondition(Map params) {
        return caseLawyerMapper.selectByMap(params);
    }

    @Override
    @Transactional(isolation = Isolation.DEFAULT, rollbackFor = Exception.class)
    public boolean transferLawyer(TransferParam params) {
        try {
            Long newLawyerId = params.getNewLawyerId();   //新的律师
            LawUserVO newLawyer = sysUserMapper.getLawUserById(newLawyerId);    //查找新的律师
            String transferCaseIds = params.getCaseIds();   //要转移的案件IDS
            List<Long> caseIdList = StrUtil.split(transferCaseIds, ",").stream().map(Long::parseLong).collect(Collectors.toList()); //获取要转移的案件ID
            //根据案件ID去查询【case_lawyer】表中原来的主办律师信息
            List<CaseLawyer> caseLawyers = caseLawyerMapper.selectByCaseIdPrime(caseIdList);
            //将【case_lawyer】表中原来的主办律师信息设置为【原承办律师1】
            List<Long> clIds = caseLawyers.stream().map(CaseLawyer::getId).collect(Collectors.toList());
            caseLawyerMapper.updateByIds(clIds);

            //组装新的主办律师信息并插入到【case_lawyer】表中
            ArrayList<CaseLawyer> insert = new ArrayList<>();
            for (Long item : caseIdList) {
                CaseLawyer caseLawyer = new CaseLawyer();
                caseLawyer.setCaseId(item);
                caseLawyer.setLawyerId(newLawyerId);
                caseLawyer.setLawyerName(newLawyer.getNickName());
                caseLawyer.setLawyerType(0);
                caseLawyer.setIsPrime(0);
                insert.add(caseLawyer);
            }
            this.saveBatch(insert);

            //修改案件信息表中的【案件涉及律师ID】
            for (Long id : caseIdList) {
                List<CaseLawyer> caseLawyersNow = caseLawyerMapper.selectAllPrimeLawyerByCaseId(id); //查询【case_lawyer】表新的案件主办律师信息
                String lawIdsStr = caseLawyersNow.stream().map(item -> item.getLawyerId().toString()).collect(Collectors.joining(","));
                System.out.println(caseLawyersNow);
                caseInformationMapper.updateLawyerIds(id, lawIdsStr);  //修改案件信息表中的【案件涉及律师ID】为转移后的律师ID
            }

            return true;
        }catch (Exception e){
            e.printStackTrace();
            throw new RuntimeException("转接失败");
        }
    }

}
