package com.tcctlo.law.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.deepoove.poi.XWPFTemplate;
import com.tcctlo.common.utils.StringUtils;
import com.tcctlo.law.entity.ContractTemplate;
import com.tcctlo.law.entity.wordTemplateEntity.BaseWordEntity;
import com.tcctlo.law.mapper.ContractTemplateMapper;
import com.tcctlo.law.service.IContractTemplateService;
import com.tcctlo.law.tools.FileUpload;
import org.dromara.x.file.storage.core.FileInfo;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * <p>
 * 合同模板 服务实现类
 * </p>
 *
 * @author
 * @since 2025-02-18
 */
@Service
public class ContractTemplateServiceImpl extends ServiceImpl<ContractTemplateMapper, ContractTemplate> implements IContractTemplateService {


    @Resource
    private ContractTemplateMapper contractTemplateMapper;

    @Resource
    private FileUpload fileUpload;

    @Value("${serviceFilePath}")
    private String serviceFilePath;

    @Value("${generatedWordPath}")
    private String generatedWordPath;

    /*@Override
    public Page<ContractTemplate> list(Integer pageNo, Integer pageSize) {
        return contractTemplateMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }*/


    @Override
    public Page<ContractTemplate> list(Map<String, Object> params) {
//        return contractTemplateMapper.selectPage(new Page<>((Integer) params.get("current"), (Integer) params.get("size")), new QueryWrapper<>());
        return contractTemplateMapper.selectCondition(new Page<>((Integer) params.get("current"), (Integer) params.get("size")), params);
    }

    @Override
    public ContractTemplate getById(Long id) {
        ContractTemplate contractTemplate = contractTemplateMapper.selectById(id);
        return contractTemplate;
    }


    /*@Override
    public Integer create(ContractTemplate contractTemplate) {
        try {
            URL url = new URL(contractTemplate.getFileUrl());
            String filePath = serviceFilePath + UUID.randomUUID() + contractTemplate.getFileUrl().substring(contractTemplate.getFileUrl().lastIndexOf("."));
            String filePathSource = serviceFilePath + UUID.randomUUID() + "_source" + contractTemplate.getFileUrl().substring(contractTemplate.getFilePathSource().lastIndexOf("."));
//            String filePath = "/backitems/lawFirm/wordTemplate/" + UUID.randomUUID() + contractTemplate.getFileUrl().substring(contractTemplate.getFileUrl().lastIndexOf("."));
            contractTemplate.setFilePath(filePath);
            contractTemplate.setFilePathSource(filePathSource);
            URLConnection conn = url.openConnection();
            InputStream inputStream = conn.getInputStream();
            FileOutputStream fileOutputStream = new FileOutputStream(filePath);
            int bytesum = 0;
            int byteread;
            byte[] buffer = new byte[1024];
            while ((byteread = inputStream.read(buffer)) != -1) {
                bytesum += byteread;
                fileOutputStream.write(buffer, 0, byteread);
            }
            fileOutputStream.close();
        } catch (Exception e) {
            throw new RuntimeException("存储至服务器失败");
        }
        return contractTemplateMapper.insert(contractTemplate);
    }*/

    @Override
    public Integer create(ContractTemplate contractTemplate){
        try {
            if (StringUtils.isNotBlank(contractTemplate.getFileUrl())){
                URL url = new URL(contractTemplate.getFileUrl());
                String filePath = serviceFilePath + UUID.randomUUID() + contractTemplate.getFileUrl().substring(contractTemplate.getFileUrl().lastIndexOf("."));
                contractTemplate.setFilePath(filePath);
                uploadOnService(url, filePath);
            }
            if (StringUtils.isNotBlank(contractTemplate.getFileUrlSource())){
                URL fileUrlSource = new URL(contractTemplate.getFileUrlSource());
                String filePathSource = serviceFilePath + UUID.randomUUID() + "_source" + contractTemplate.getFileUrlSource().substring(contractTemplate.getFileUrlSource().lastIndexOf("."));
                contractTemplate.setFilePathSource(filePathSource);
                uploadOnService(fileUrlSource, filePathSource);
            }
        } catch (Exception e) {
            throw new RuntimeException("存储至服务器失败");
        }

        return contractTemplateMapper.insert(contractTemplate);
    }

    public void uploadOnService(URL url, String filePath) {
        try {
            URLConnection conn = url.openConnection();
            InputStream inputStream = conn.getInputStream();
            FileOutputStream fileOutputStream = new FileOutputStream(filePath);
            int bytesum = 0;
            int byteread;
            byte[] buffer = new byte[1024];
            while ((byteread = inputStream.read(buffer)) != -1) {
                bytesum += byteread;
                fileOutputStream.write(buffer, 0, byteread);
            }
            fileOutputStream.close();
        } catch (Exception e) {
            throw new RuntimeException("存储至服务器失败");
        }
    }

    @Override
    public Integer delete(Long id) {
        return contractTemplateMapper.deleteById(id);
    }

    @Override
    public Integer update(ContractTemplate contractTemplate) {
        return contractTemplateMapper.updateById(contractTemplate);
    }

    @Override
    public Integer deleteTemplate(Map<String, String> param) {
        List<Long> ids = Arrays.stream(param.get("ids").split(","))
                .mapToLong(Long::parseLong)
                .boxed()
                .collect(Collectors.toList());
        return contractTemplateMapper.deleteTemplate(ids);
    }

    @Override
    public String getWord(Map<String, Long> param) throws Exception {
        Long wordId = param.get("wordId");
        Long caseId = param.get("caseId");
        ContractTemplate contractTemplate = contractTemplateMapper.selectById(wordId);
        if (caseId == null) {
            return contractTemplate.getFileUrlSource();
        }
        if (StringUtils.isBlank(contractTemplate.getFilePath())){
            return contractTemplate.getFileUrlSource();
        }
        List<BaseWordEntity> list = contractTemplateMapper.selectWordParam(caseId);
        System.out.println(list);
        BaseWordEntity baseWordEntity = new BaseWordEntity();
        String firstParty = list.stream().map(item -> item.getFirstParty()).collect(Collectors.joining("、"));
        baseWordEntity.setFirstParty(firstParty);
        baseWordEntity.setSolicitor(list.get(0).getSolicitor());
        baseWordEntity.setSocialCreditCode(list.get(0).getSocialCreditCode());
        baseWordEntity.setAddress(list.get(0).getAddress());
        String savePath = generatedWordPath + UUID.randomUUID().toString() + ".docx";
        XWPFTemplate template = XWPFTemplate.compile(contractTemplate.getFilePath()).render(baseWordEntity);
        FileOutputStream out = new FileOutputStream(savePath);
        template.write(out);
        out.flush();
        out.close();
        template.close();
        File file = new File(savePath);
        FileInfo fileInfo = fileUpload.uploadFile(file);
        String url = fileInfo.getUrl();
        System.out.println(url);
        return url;
    }

}
