package com.tcctlo.law.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctlo.common.core.domain.model.LoginUser;
import com.tcctlo.common.utils.SecurityUtils;
import com.tcctlo.law.entity.FileManager;
import com.tcctlo.law.entity.InvoiceRecord;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.mapper.FileManagerMapper;
import com.tcctlo.law.vo.InvoiceRecordVO;
import com.tcctlo.law.mapper.InvoiceRecordMapper;
import com.tcctlo.law.service.IInvoiceRecordService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
* <p>
* 开票记录表 服务实现类
* </p>
*
* @author 
* @since 2025-03-07
*/
@Service
public class InvoiceRecordServiceImpl extends ServiceImpl<InvoiceRecordMapper,InvoiceRecord> implements IInvoiceRecordService {


    @Resource
    private InvoiceRecordMapper invoiceRecordMapper;

    @Resource
    private FileManagerServiceImpl fileManagerService;

    @Resource
    private FileManagerMapper fileManagerMapper;

    @Override
    public Page<InvoiceRecord> list(Integer pageNo, Integer pageSize) {
        return invoiceRecordMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }

    @Override
    public InvoiceRecord getById(Long id) {
        InvoiceRecord invoiceRecord = invoiceRecordMapper.selectById(id);
        return invoiceRecord;
    }

    @Override
    public Boolean create(InvoiceRecordVO invoiceRecord) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        Long userId = loginUser.getUserId();
        String nickName = loginUser.getUser().getNickName();
        invoiceRecord.setInvoiceUserId(userId);
        invoiceRecord.setInvoiceUserName(nickName);

        List<FileManager> fileManager = invoiceRecord.getFileManager();
        fileManager.stream().peek(item -> item.setFileType(3)).collect(Collectors.toList());
        fileManagerService.saveBatch(fileManager);
        String ids = fileManager.stream().map(item -> item.getId().toString()).collect(Collectors.joining(","));
        invoiceRecord.setInvoiceFileUrl(ids);
        int insert = invoiceRecordMapper.insert(invoiceRecord);
        return insert > 0;
    }

    @Override
    public Integer delete(Long id) {
        return invoiceRecordMapper.deleteById(id);
    }

    @Override
    public Integer update(InvoiceRecord invoiceRecord) {
        return invoiceRecordMapper.updateById(invoiceRecord);
    }

    @Override
    public Integer deleteBatch(Map<String, String> params) {
        List<Long> ids = Arrays.stream(params.get("ids").split(","))
                .map(Long::parseLong)
                .collect(Collectors.toList());

        return invoiceRecordMapper.deleteBatch(ids);
    }

    @Override
    public List<InvoiceRecordVO> selectByCaseId(Long caseId) {
        List<InvoiceRecordVO> invoiceRecords = invoiceRecordMapper.selectByCaseId(caseId);
        invoiceRecords.stream().peek(item -> {
            List<Long> collect = Arrays.stream(item.getInvoiceFileUrl().split(",")).map(Long::parseLong).collect(Collectors.toList());
            item.setFileManager(fileManagerMapper.selectByCRid(collect));
        }).collect(Collectors.toList());
        return invoiceRecords;
    }

}
